@@ -1,5 +1,3 @@
-# $Id$
-
 classifiers = """
 License :: Public Domain
 Operating System :: POSIX
@@ -20,7 +18,7 @@ parallel computing
 metadata = {             
     'author'           : 'Lisandro Dalcin',
     'author_email'     : 'dalcinl@users.sourceforge.net',
-    'url'              : 'http://www.cimec.org.ar/python',
+    'url'              : 'http://code.google.com/p/petsc4py/',
     'classifiers'      : [c for c in classifiers.split('\n') if c],
     'keywords'         : [k for k in keywords.split('\n')    if k],
     'license'          : 'Public Domain',
