@@ -1,5 +1,3 @@
-# $Id$
-
 # --------------------------------------------------------------------
 
 __all__ = ['setup',
@@ -36,7 +34,7 @@ import cfgutils
 if not hasattr(sys, 'version_info') or \
        sys.version_info < (2, 4, 0,'final'):
     raise SystemExit("Python 2.4 or later is required "
-                     "to build PETSc package.")
+                     "to build PETSc for Python.")
 
 # --------------------------------------------------------------------
 
@@ -57,9 +55,23 @@ class PetscConfig:
         self.PETSC_ARCH = petsc_arch
         self.petscconf = self._get_petsc_conf(self.PETSC_DIR,
                                               self.PETSC_ARCH)
-        self.mpiconf  = self._get_mpi_conf(self.petscconf)
+        ## self.mpiconf  = self._get_mpi_conf(self.petscconf)
         self.language = self._get_lang(self['PETSC_LANGUAGE'])
 
+    ## def _get_mpi_conf(self, petsc_conf):
+    ##     # try to find MPI configuration from PETSc
+    ##     mpicompiler = petsc_conf.get('PCC')
+    ##     if mpicompiler:
+    ##         for opts in ('-showme:compile -showme:link',    # LAM/OMPI
+    ##                      '-shlib -compile_info -link_info', # MPICH
+    ##                      '-compile_info -link_info',        # MPICH2
+    ##                      ):
+    ##             cmdline = '%s %s' % (mpicompiler, opts)
+    ##             flags = cfgutils.command(cmdline)
+    ##             if flags: # found !
+    ##                 return cfgutils.flaglist(flags)
+    ##     return { }
+    
     def _get_petsc_conf(self, petsc_dir, petsc_arch):
         bmake = os.path.join(petsc_dir,  'bmake')
         petscvars = os.path.join(bmake,'common',    'variables')
@@ -68,25 +80,11 @@ class PetscConfig:
         confstr += 'PETSC_ARCH = %s\n' % petsc_arch
         confstr += open(petscvars).read()
         confstr += open(petscconf).read()
-        confstr += 'PACKAGES_INCLUDES = ${MPI_INCLUDE} ${X11_INCLUDE} ${BLASLAPACK_INCLUDE}'
+        confstr += 'PACKAGES_INCLUDES = ${MPI_INCLUDE} ${X11_INCLUDE} ${BLASLAPACK_INCLUDE}\n'
         confstr += 'PACKAGES_LIBS = ${MPI_LIB} ${X11_LIB} ${BLASLAPACK_LIB}\n'
         confdct = cfgutils.makefile(StringIO(confstr))
         return confdct
 
-    def _get_mpi_conf(self, petsc_conf):
-        # try to find MPI configuration from PETSc
-        mpicompiler = petsc_conf.get('PCC')
-        if mpicompiler:
-            for opts in ('-showme:compile -showme:link',    # LAM/OMPI
-                         '-shlib -compile_info -link_info', # MPICH
-                         '-compile_info -link_info',        # MPICH2
-                         ):
-                cmdline = '%s %s' % (mpicompiler, opts)
-                flags = cfgutils.command(cmdline)
-                if flags: # found !
-                    return cfgutils.flaglist(flags)
-        return { }
-
     def _get_lang(self, lang):
         langs = {'CONLY':'c', 'CXXONLY':'c++'}
         return langs[lang]
@@ -98,15 +96,17 @@ class PetscConfig:
 
     def _configure_extension(self, extension):
         # MPI configuration
-        self._configure_ext(extension, self.mpiconf)
+        ## self._configure_ext(extension, self.mpiconf)
         # define macros
         macros = [('PETSC_DIR',  self.PETSC_DIR),
-                  ('PETSC_ARCH', self.PETSC_ARCH),
-                  ('__SDIR__',   '\'\"petsc4py/\"\'')]
+                  ('PETSC_ARCH', self.PETSC_ARCH)]
         extension.define_macros.extend(macros)
         # includes and libraries
         petsc_inc = cfgutils.flaglist(self['PETSC_INCLUDE'])
-        petsc_lib = cfgutils.flaglist(self['PETSC_LIB'])
+        petsc_lib_info = (self['C_SH_LIB_PATH'],
+                          self['PETSC_LIB_DIR'],
+                          self['PETSC_LIB_BASIC'])
+        petsc_lib = cfgutils.flaglist('%s -L%s %s' % petsc_lib_info)
         self._configure_ext(extension, petsc_inc, preppend=True)
         self._configure_ext(extension, petsc_lib)
         # extra configuration
@@ -142,7 +142,6 @@ class PetscConfig:
         log.info('scalar-type: %s' % scalar_type)
         log.info('precision:   %s' % precision)
 
-
 # --------------------------------------------------------------------
 
 class Extension(_Extension):
@@ -203,7 +202,13 @@ class config(_config):
             if not petsc_arch:
                 log.warn("default PETSC_ARCH not found")
                 return None
-        petsc_arch = petsc_arch.split(',')
+        if os.pathsep in petsc_arch:
+            arch_sep = os.pathsep
+        else:
+            arch_sep = ','
+        petsc_arch = petsc_arch.split(arch_sep)
+        petsc_arch = cfgutils.unique(petsc_arch)
+        petsc_arch = [arch for arch in petsc_arch if arch]
         return self._chk_petsc_arch(petsc_dir, petsc_arch)
         
     def _chk_petsc_arch(self, petsc_dir, petsc_arch):
@@ -280,9 +285,10 @@ class build_py(_build_py):
         petsc_dir  = config.petsc_dir
         petsc_arch = config.petsc_arch
         if petsc_dir:
-            PETSC_DIR  = petsc_dir 
+            PETSC_DIR  = petsc_dir
         if petsc_arch:
-            PETSC_ARCH = petsc_arch[0]
+            separator   = os.path.pathsep
+            PETSC_ARCH = separator.join(petsc_arch)
         log.info('writing %s' % py_file)
         config_py = open(py_file, 'w')
         config_py.write(config_data % vars())
@@ -316,7 +322,10 @@ class build_src(_build_src):
         sources, py_files = self.filter_py_files(all_src)
         for py_file in py_files:
             if os.path.exists(py_file):
-                os.remove(py_file)
+                try:
+                    os.remove(py_file)
+                except OSError:
+                    pass
         return sources
 
     def run(self):
@@ -391,6 +400,9 @@ class build_ext(_build_ext):
                 config.log_info()
                 pkgpath, newext = self._copy_ext(ext)
                 config.configure(newext)
+                version = self.distribution.get_version()
+                distdir = '\'\"petsc4py-%s/\"\'' % version
+                newext.define_macros.append(('__SDIR__', distdir))
                 self._build_ext_arch(newext, pkgpath, arch)
 
     def get_outputs(self):
