@@ -57,9 +57,15 @@ class Error(RuntimeError):
         comm_world = _petsc.PetscGetCommWorld()
         wsize = _petsc.PetscCommGetSize(comm_world)
         wrank = _petsc.PetscCommGetRank(comm_world)
+        try:
+            fd = _sys.stderr
+        except AttributeError:
+            fd = None
+        if not isinstance(fd, file):
+            fd = _sys.__stderr__
         for error in _petsc.PetscTraceBackError:
             message = '[%*d] %s\n' % (len(str(wsize-1)), wrank, error)
-            _petsc.PetscFPrintf(comm_self, _sys.stderr, message)
+            _petsc.PetscFPrintf(comm_self, fd, message)
 
 # --------------------------------------------------------------------
 
