@@ -144,7 +144,7 @@ class IS(Object):
 
     def duplicate(self):
         """
-        Creates a duplicate copy of an index set.
+        Create a duplicate copy of an index set.
 
         :Returns:
           - the duplicated index set.
@@ -153,38 +153,38 @@ class IS(Object):
 
     def getSize(self):
         """
-        Returns the global length of an index set.
+        Return the global length of an index set.
         """
         return _petsc.ISGetSize(self)
 
     def getLocalSize(self):
         """
-        Returns the local length of an index set.
+        Return the local length of an index set.
         """
         return _petsc.ISGetLocalSize(self)
 
     def getSizes(self):
         """
-        Returns the local and global lengths of an index set.
+        Return the local and global lengths of an index set.
         """
         return _petsc.ISGetLocalSize(self), _petsc.ISGetSize(self)
 
     def getSizeBlock(self):
         """
-        Returns the number of blocks in a block index set.
+        Return the number of blocks in a block index set.
         """
         return _petsc.ISBlockGetSize(self)
 
     def getBlockSize(self):
         """
-        Returns the number of elements in a block for a block index
+        Return the number of elements in a block for a block index
         set.
         """
         return _petsc.ISBlockGetBlockSize(self)
 
     def getIndices(self, indices=None):
         """
-        Returns the indices stored in the index set
+        Return the indices stored in the index set
         """
         if indices is None:
             lsize   = _petsc.ISGetLocalSize(self)
@@ -194,32 +194,32 @@ class IS(Object):
 
     def isPermutation(self):
         """
-        Determines whether the index set has been declared to be a
+        Determine whether the index set has been declared to be a
         permutation.
         """
         return bool(_petsc.ISPermutation(self))
 
     def setPermutation(self):
         """
-        Informs the index set that it is a permutation.
+        Inform the index set that it is a permutation.
         """
         return _petsc.ISSetPermutation(self)
 
     def isIdentity(self):
         """
-        Determines whether index set is the identity mapping.
+        Determine whether index set is the identity mapping.
         """
         return bool(_petsc.ISIdentity(self))
 
     def setIdentity(self):
         """
-        Informs the index set that it is an identity.
+        Inform the index set that it is an identity.
         """
         _petsc.ISSetIdentity(self)
 
     def invertPermutation(self, nlocal=None):
         """
-        Creates a new permutation that is the inverse of
+        Create a new permutation that is the inverse of
         a given permutation.
 
         :Parameters:
@@ -244,19 +244,19 @@ class IS(Object):
 
     def equal(self, iset):
         """
-        Compares if two index sets have the same set of indices.
+        Compare if two index sets have the same set of indices.
         """
         return bool(_petsc.ISEqual(self, iset))
 
     def sort(self):
         """
-        Sorts the indices of an index set.
+        Sort the indices of an index set.
         """
         _petsc.ISSort(self)
 
     def isSorted(self):
         """
-        Checks the indices to determine whether they have been sorted.
+        Check the indices to determine whether they have been sorted.
 
         .. note::
            For parallel index sets this only indicates if the local
@@ -267,18 +267,17 @@ class IS(Object):
 
     def sum(self, iset):
         """
-        Computes the sum (union) of two index sets in place.
+        Computes the sum (union) of two index sets.
 
         .. note:: If ``n1`` and ``n2`` are the sizes of the sets, this
-           takes ``O(n1+n2)`` time; if `iset` is a subset of `self`,
-           `self` is left unchanged, otherwise `self` is
-           reallocated. Both index sets need to be sorted on input.
+           takes ``O(n1+n2)`` time. Both index sets need to be sorted
+           on input.
         """
-        _petsc.ISSum(self, iset)
+        return _petsc.ISSum(self, iset)
 
     def expand(self, iset):
         """
-        Computes the sum (union) of two index sets.
+        Compute the sum (union) of two index sets.
 
         .. note:: Negative values are removed from the lists. This
            requires O(imax-imin) memory and O(imax-imin) work, where
@@ -289,7 +288,7 @@ class IS(Object):
         
     def difference(self, iset):
         """
-        Computes the difference between two index sets.
+        Compute the difference between two index sets.
 
         .. note:: Negative values are removed from the lists. `iset`
            may have values that are not in `self`. This requires
@@ -300,7 +299,7 @@ class IS(Object):
 
     def allGather(self):
         """
-        Given an index set on each processor, generates a large index
+        Given an index set on each processor, generate a large index
         set (same on each processor) by concatenating together each
         processors index set.
 
@@ -365,13 +364,13 @@ class ISStride(IS):
         
     def toGeneral(self):
         """
-        Converts a stride index set to a general index set.
+        Convert a stride index set to a general index set.
         """
         _petsc.ISStrideToGeneral(self)
         
     def getInfo(self):
         """
-        Returns the first index in a stride index set and the stride
+        Return the first index in a stride index set and the stride
         width.
         """
         return tuple(_petsc.ISStrideGetInfo(self))
@@ -413,7 +412,7 @@ class LGMapping(Object):
 
     def create(self, indices, comm=None):
         """
-        Creates a mapping between a local (0 to n) ordering and a
+        Create a mapping between a local (0 to n) ordering and a
         global parallel ordering.
 
         :Parameters:
@@ -432,8 +431,9 @@ class LGMapping(Object):
 
     def createBlock(self, lgmap, bsize):
         """
-        Creates a blocked index version of an LGMapping that is appropriate
-        for `Vec.setLGMappingBlock()` and `Mat.setLGMappingBlock()`.
+        Create a blocked index version of an LGMapping that is
+        appropriate for `Vec.setLGMappingBlock()` and
+        `Mat.setLGMappingBlock()`.
 
         :Parameters:
           - `lgmap`: base local to global mapping.
@@ -444,14 +444,14 @@ class LGMapping(Object):
     
     def getSize(self):
         """
-        Gets the local size of a local to global mapping.
+        Get the local size of a local to global mapping.
         """
         return _petsc.LGMappingGetSize(self)
 
     def getInfo(self):
         """
-        Gets the neighbor information for each processor and each
-        index shared by more than one processor
+        Get the neighbor information for each processor and each index
+        shared by more than one processor
 
         :Returns:
             - dictionary where **keys** are neighboring processors
@@ -463,12 +463,12 @@ class LGMapping(Object):
            empty.
         """
         neighs, nodes = _petsc.LGMappingGetInfo(self)
-        return dict((n, nodes[i]) for i, n in enumerate(neighs))
+        return dict([(n, nodes[i]) for i, n in enumerate(neighs)])
 
     def apply(self, indices, result=None):
         """
-        Takes a list of integers in a local numbering and converts
-        them to the global numbering.
+        Take a list of integers in a local numbering and converts them
+        to the global numbering.
 
         :Parameters:
            - `indices`: input array with indices in local numbering.
@@ -494,7 +494,7 @@ class LGMapping(Object):
 
     def applyInverse(self, indices, map_type=None):
         """
-        Provides the local numbering for a list of integers specified
+        Provide the local numbering for a list of integers specified
         with a global numbering.
         """
         map_type = _petsc.get_attr(LGMapping.GLMapType, map_type)
