@@ -48,6 +48,8 @@ from petsc4py.lib import _petsc
 from petsc4py.lib import _numpy
 
 from petsc4py.Object import Object
+from petsc4py.Vec    import Vec
+from petsc4py.Mat    import Mat
 
 # --------------------------------------------------------------------
 
@@ -108,15 +110,15 @@ class KSP(Object):
         Norm that is passed in the Krylov convergence test routines.
         """
         # native
-        NO_NORM               = _petsc.KSP_NO_NORM
-        PRECONDITIONED_NORM   = _petsc.KSP_PRECONDITIONED_NORM
-        UNPRECONDITIONED_NORM = _petsc.KSP_UNPRECONDITIONED_NORM
-        NATURAL_NORM          = _petsc.KSP_NATURAL_NORM
+        NORM_NO               = _petsc.KSP_NORM_NO
+        NORM_PRECONDITIONED   = _petsc.KSP_NORM_PRECONDITIONED
+        NORM_UNPRECONDITIONED = _petsc.KSP_NORM_UNPRECONDITIONED
+        NORM_NATURAL          = _petsc.KSP_NORM_NATURAL
         # aliases
-        NONE             = NO_NORM
-        PRECONDITIONED   = PRECONDITIONED_NORM
-        UNPRECONDITIONED = UNPRECONDITIONED_NORM
-        NATURAL          = NATURAL_NORM
+        NONE = NO        = NORM_NO
+        PRECONDITIONED   = NORM_PRECONDITIONED
+        UNPRECONDITIONED = NORM_UNPRECONDITIONED
+        NATURAL          = NORM_NATURAL
 
     class ConvergedReason:
         """
@@ -154,7 +156,7 @@ class KSP(Object):
         DEFAULT = _petsc.KSPDefaultConverged
         SKIP    = _petsc.KSPSkipConverged
         def __call__(self, ksp, its, rnorm):
-            """Calls KSP.ConvergenceTest.DEFAULT"""
+            """Call KSP.ConvergenceTest.DEFAULT"""
             return self.DEFAULT(ksp, its, rnorm)
 
     class Monitor(object):
@@ -279,7 +281,7 @@ class KSP(Object):
            - `divtol`: the divergence tolerance.
            - `max_it`: maximum number of iterations.
         """
-        return _petsc.KSPGetTolerances(self)
+        return list(_petsc.KSPGetTolerances(self))
 
     def setTolerances(self, rtol=None, atol=None, divtol=None, max_it=None):
         """
@@ -304,7 +306,7 @@ class KSP(Object):
         
     def getInitialGuessNonzero(self):
         """
-        Determines whether the KSP solver is using a zero initial
+        Determine whether the KSP solver is using a zero initial
         guess.
         """
         return bool(_petsc.KSPGetInitialGuessNonzero(self))
@@ -331,6 +333,22 @@ class KSP(Object):
         """
         _petsc.KSPSetInitialGuessKnoll(self, flag)
 
+    def getDiagonalScale(self):
+        """
+        Determine whether the KSP solver scales the matrix and right hand side.
+        """
+        flag = _petsc.KSPGetDiagonalScale(self)
+        fix  = _petsc.KSPGetDiagonalScaleFix(self)
+        return (flag, fix)
+    
+    def setDiagonalScale(self, flag, fix=False):
+        """
+        Tells the KSP solver to symmetrically diagonally scale the system
+        before solving. This actually CHANGES the matrix and right hand side.
+        """
+        _petsc.KSPSetDiagonalScale(self, flag)
+        _petsc.KSPSetDiagonalScaleFix(self, fix)
+
     def getRhs(self):
         """
         Get the right-hand-side vector for the linear system to be
@@ -825,7 +843,7 @@ class PCShell(PC):
     operator.
     """
     __metaclass__ = PC.Type(PC.Type.SHELL)
-            
+
     def getContext(self):
         """
         Get the user-provided context object associated with a shell
