@@ -50,6 +50,7 @@ from petsc4py.lib import _matops
 from petsc4py.lib import _numpy
 
 from petsc4py.Object import Object
+from petsc4py.Vec    import Vec
 
 # --------------------------------------------------------------------
 
@@ -694,8 +695,8 @@ class Mat(Object):
 
     def convert(self, mat_type, result=None):
         """
-        Convert a matrix to another matrix, either of the same
-        or different type.
+        Convert a matrix to another matrix, either of the same or
+        different type.
         """
         mat_type = _petsc.get_attr(Mat.Type, mat_type)
         return _petsc.MatConvert(self, mat_type, result)
@@ -728,7 +729,7 @@ class Mat(Object):
         Test whether a matrix is another one's transpose, 
         or its own, in which case it tests symmetry.
         """
-        if  mat is None:
+        if mat is None:
             mat = self
         return bool(_petsc.MatIsTranspose(self, mat, tol))
 
@@ -792,11 +793,8 @@ class Mat(Object):
             cols = _numpy.asarray(cols, _petsc.PetscInt)
             shape = (_numpy.size(rows), _numpy.size(cols))
             values = _numpy.empty(shape, _petsc.PetscScalar)
-            retval = values
-        else:
-            retval = None
         _petsc.MatGetValues(self, rows, cols, values)
-        return retval
+        return values
 
     def setValue(self, row, col, value, insert_mode=None):
         """
@@ -857,7 +855,7 @@ class Mat(Object):
     def setValuesBlockedLocal(self, rows, cols, values,
                               insert_mode=None):
         """
-        Inserts or adds values into certain locations of a matrix,
+        Insert or add values into certain locations of a matrix,
         using a local ordering of the nodes a block at a time.
         """
         _petsc.MatSetValuesBlockedLocal(self, rows, cols, values,
@@ -865,7 +863,7 @@ class Mat(Object):
 
     def storeValues(self):
         """
-        Stashes a copy of the matrix values.
+        Stash a copy of the matrix values.
 
         .. tip:: This allows reuse of the linear part of
            a Jacobian, while recomputing the nonlinear portion.
@@ -874,7 +872,7 @@ class Mat(Object):
         
     def retrieveValues(self):
         """
-        Retrieves the copy of the matrix values.
+        Retrieve the copy of the matrix values.
 
         .. tip:: This allows reuse of the linear part of
            a Jacobian, while recomputing the nonlinear portion.
@@ -883,47 +881,53 @@ class Mat(Object):
     
     def assemblyBegin(self, assembly=None):
         """
-        Begins assembling the matrix.  This routine should
-        be called after completing all calls to `SetValues()`.
+        Begin assembling the matrix.  This routine should
+        be called after completing all calls to `setValues()`.
         """
         _petsc.MatAssemblyBegin(self, assembly)
 
     def assemblyEnd(self, assembly=None):
         """
-        Completes assembling the matrix.  This routine should
-        be called after `AssemblyBegin()`.
+        Complete assembling the matrix.  This routine should be called
+        after `assemblyBegin()`.
         """
         _petsc.MatAssemblyEnd(self, assembly)
 
     def assemble(self, assembly=None):
         """
-        Calls ``AssemblyBegin()` and `AssemblyEnd()`.
+        Call ``assemblyBegin()` and `assemblyEnd()`.
         """
         _petsc.MatAssemblyBegin(self, assembly)
         _petsc.MatAssemblyEnd(self, assembly)
 
     def isAssembled(self):
         """
-        Indicates if a matrix has been assembled and is ready for use,
+        Indicate if a matrix has been assembled and is ready for use,
         for example, in matrix-vector product.
         """
         return bool(_petsc.MatAssembled(self))
 
     assembled = isAssembled
 
-    def getRowIJ(self, symmetric=False):
+    def getRow(self, row):
         """
-        Returns the compressed row storage i and j indices for
-        sequential matrices.
+        Get a row of a matrix.
         """
-        return tuple(_petsc.MatGetRowIJ(self, symmetric))
+        return tuple(_petsc.MatGetRow(self, row))
 
-    def getColumnIJ(self, symmetric=False):
+    def getRowIJ(self, symmetric=False, blockcompressed=False):
         """
-        Returns the compressed column storage i and j indices for
+        Return the compressed row storage i and j indices for
         sequential matrices.
         """
-        return tuple(_petsc.MatGetColumnIJ(self, symmetric))
+        return tuple(_petsc.MatGetRowIJ(self, symmetric, blockcompressed))
+
+    def getColumnIJ(self, symmetric=False, blockcompressed=False):
+        """
+        Return the compressed column storage i and j indices for
+        sequential matrices.
+        """
+        return tuple(_petsc.MatGetColumnIJ(self, symmetric, blockcompressed))
 
     def setNullSpace(self, nullsp):
         """
@@ -953,18 +957,18 @@ class Mat(Object):
         """
         return _petsc.MatGetVecs(self)
 
-    def getVecLeft(self):
-        """
-        Get a vector that the matrix vector product can be stored in.
-        """
-        return _petsc.MatGetVecLeft(self)
-
     def getVecRight(self):
         """
         Get vector that the matrix can be multiplied against.
         """
         return _petsc.MatGetVecRight(self)
 
+    def getVecLeft(self):
+        """
+        Get a vector that the matrix vector product can be stored in.
+        """
+        return _petsc.MatGetVecLeft(self)
+
     def mult(self, x, y):
         """
         A * x -> y
@@ -1003,12 +1007,16 @@ class Mat(Object):
         """
         _petsc.MatMultTransposeConstrained(self, x, y)
 
-    def getDiagonal(self, diag):
+    def getDiagonal(self, diag=None):
         """
-        Get the diagonal of a matrix in a vector, A[i,i] -> diag[i]
+        Get the diagonal of a matrix in a vector, diag[i] <- A[i,i]
 
         :Parameters:
-          - `vec`: the vector for storing the diagonal.
+          - `diag`: the vector for storing the diagonal. If not
+            provided, a new vector is generated.
+
+        :Returns:
+          - `diag`: the vector storing the diagonal.
 
         .. note:: For the `SEQAIJ` matrix format, this routine may
            also be called on a LU factored matrix; in that case it
@@ -1016,39 +1024,63 @@ class Mat(Object):
            returns the entries permuted by the row and column
            permutation used during the symbolic factorization.
         """
+        if diag is None:
+            diag = _petsc.MatGetVecLeft(self)
         _petsc.MatGetDiagonal(self, diag)
+        return diag
 
-    def getRowMax(self, vec):
+    def getRowMax(self, vec=None, idx=None):
+        """
+        Get the maximum value (of the real part) of each row of the
+        matrix
+        """
+        if vec is None:
+            vec = _petsc.MatGetVecLeft(self)
+        _petsc.MatGetRowMax(self, vec, idx)
+        return vec
+
+    def getRowMaxAbs(self, vec=None, idx=None):
         """
         Get the maximum value (in absolute value) of each row of the
         matrix
         """
-        _petsc.MatGetRowMax(self, vec)
+        if vec is None:
+            vec = _petsc.MatGetVecLeft(self)
+        _petsc.MatGetRowMaxAbs(self, vec, idx)
+        return vec
 
-    def conjugate(self):
+    def conjugate(self, inplace=False):
         """
-        Replaces the matrix values with their complex conjugates.
+        Compute an in-place or out-of-place complex conjugate of a
+        matrix.
         """
-        _petsc.MatConjugate(self)
+        if inplace:
+            mat = self
+        else:
+            mat = _petsc.MatDuplicate(self, _petsc.MAT_COPY_VALUES)
+        _petsc.MatConjugate(mat)
+        return mat
 
-    def transpose(self, inplace=True):
+    def transpose(self, inplace=False):
         """
         Compute an in-place or out-of-place transpose of a matrix.
         
         :Parameters:
-          - `inplace`: defaults to `True`.
+          - `inplace`: defaults to `False`.
 
         :Returns:
-          - the transposed matrix, when `inplace` is `False`.
+          - the transposed matrix.
         """
         if inplace:
             _petsc.MatTranspose(self, 1)
+            return self
         else:
             return _petsc.MatTranspose(self, 0)
+        
 
     def permute(self, row_perm, col_perm):
         """
-        Creates a new matrix with rows and columns permuted from the
+        Create a new matrix with rows and columns permuted from the
         original.
 
         :Parameters:
@@ -1064,7 +1096,7 @@ class Mat(Object):
         
     def permuteSparsify(self, band, frac, tol, row_perm, col_perm):
         """
-        Creates a new matrix with rows and columns permuted from the
+        Create a new matrix with rows and columns permuted from the
         original and sparsified to the prescribed tolerance.
 
         :Parameters:
@@ -1079,6 +1111,21 @@ class Mat(Object):
         return _petsc.MatPermuteSparsify(self, band, frac, tol,
                                          row_perm, col_perm)
 
+    def setDiagonal(self, D, insert_mode=None):
+        """
+        Compute Y <- Y + D (where D is a diagonal matrix that is
+        represented as a vector), or Y[i,i] <- D[i] (if insertion mode
+        is `INSERT_VALUES`).
+
+        :Parameters:
+          - `D`: the vector representing a diagonal matrix.
+          - `insert_mode`: either `INSERT_VALUES` (default)
+            or `ADD_VALUES`
+        """
+        _petsc.MatDiagonalSet(self, D, insert_mode)
+
+    diagonalSet = setDiagonal
+
     def diagonalScale(self, L, R):
         """
         Scales a matrix on the left and right by diagonal matrices
@@ -1094,18 +1141,6 @@ class Mat(Object):
         """
         _petsc.MatDiagonalScale(self, L, R)
 
-    def diagonalSet(self, D, insert_mode=None):
-        """
-        Compute Y <- Y + D (where D is a diagonal matrix that is
-        represented as a vector), or Y[i,i] <- D[i] (if insertion mode
-        is `INSERT_VALUES`).
-
-        :Parameters:
-          - `D`: the vector representing a diagonal matrix.
-          - `insert_mode`: either `INSERT_VALUES` or `ADD_VALUES`
-        """
-        _petsc.MatDiagonalSet(self, D, insert_mode)
-
     def norm(self, norm_type=None):
         """
         Calculates various norms of a matrix.
@@ -1123,15 +1158,15 @@ class Mat(Object):
 
     def zeroEntries(self):
         """
-        Zeros all entries of a matrix.  For sparse matrices this
+        Set to zero all entries of a matrix.  For sparse matrices this
         routine retains the old nonzero structure.
         """
         _petsc.MatZeroEntries(self)
 
     def zeroRows(self, rows, diag=1.0):
         """
-        Zeros all entries (except possibly the main diagonal) of a set
-        of rows of a matrix.
+        Set to zero all entries (except possibly the main diagonal) of
+        a set of rows of a matrix.
 
         :Parameters:
           - `rows`: index set of rows to remove.
@@ -1162,8 +1197,8 @@ class Mat(Object):
 
     def zeroRowsLocal(self, rows, diag=1.0):
         """
-        Zeros all entries (except possibly the main diagonal) of a set
-        of rows of a matrix; using local numbering of rows.
+        Set to zero all entries (except possibly the main diagonal) of
+        a set of rows of a matrix; using local numbering of rows.
 
         :Parameters:
           - `isrow`: index set of rows to remove
@@ -1192,8 +1227,8 @@ class Mat(Object):
     @staticmethod
     def merge(mat, outmat=None, comm=None, csize=None):
         """
-        Creates a single large PETSc matrix by concatenating
-        sequential matrices from each processor
+        Create a single large PETSc matrix by concatenating sequential
+        matrices from each processor
         """
         if csize is None:
             csize = _petsc.PETSC_DECIDE
@@ -1209,7 +1244,7 @@ class Mat(Object):
           - `iscol`: columns for all processors you wish to keep.
           - `csize`: number of columns *local* to this processor
             (does nothing for sequential matrices). This should
-            match the result from `Vec.GetLocalSize()` if you
+            match the result from `Vec.getLocalSize()` if you
             plan to use the matrix in a A*x; alternatively, you can
             use `DECIDE`.
            
@@ -1234,15 +1269,15 @@ class Mat(Object):
 
     def increaseOverlap(self, iset, overlap=1):
         """
-        Given a submatrix indicated by an index set, replaces the
-        index set by a larger one that represent a submatrix with
-        additional overlap.
+        Given a submatrix indicated by an index set, replace the index
+        set by a larger one that represent a submatrix with additional
+        overlap.
         """
         return _petsc.MatIncreaseOverlap(self, iset, overlap)
 
     def scale(self, alpha):
         """
-        Scales all elements of a matrix by a given number.
+        Scale all elements of a matrix by a given number.
 
         A[i,j] <- alpha * A[i,j]
 
@@ -1253,8 +1288,7 @@ class Mat(Object):
      
     def shift(self, alpha):
         """
-        Adds a scalar value to the entries in the diagonal of a
-        matrix.
+        Add a scalar value to the entries in the diagonal of a matrix.
 
         A[i,i] <-  A[i,i] + alpha 
         
@@ -1281,7 +1315,7 @@ class Mat(Object):
             matstr = _petsc.get_attr(Mat.Structure, matstr)
         _petsc.MatAXPY(self, alpha, X, matstr)
 
-    def aypx(self, alpha, X):
+    def aypx(self, alpha, X, matstr=None):
         """
         Compute Y = a*Y + X.
 
@@ -1297,7 +1331,7 @@ class Mat(Object):
             matstr = _petsc.DIFFERENT_NONZERO_PATTERN
         else:
             matstr = _petsc.get_attr(Mat.Structure, matstr)
-        _petsc.MatAYPX(self, alpha, X, matstr=None)
+        _petsc.MatAYPX(self, alpha, X, matstr)
 
     AXPY  = axpy
     AYPX  = aypx
@@ -2220,6 +2254,12 @@ class NullSpace(Object):
           - `comm`: MPI communicator (defaults to COMM_WORLD).
         """
         return _petsc.MatNullSpaceCreate(comm, has_const, vecs, self)
+
+    def setFunction(self, function):
+        """
+        Set a function that removes a null space from a vector.
+        """
+        _petsc.MatNullSpaceSetFunction(self, function)
         
     def remove(self, vec, out=None):
         """
