@@ -15,7 +15,7 @@ __date__     = '$Date$'
 __version__  = '$Version$'
 __revision__ = '$Revision$'
 
-__docformat__ = 'reST'
+__docformat__ = 'reStructuredText'
 
 # --------------------------------------------------------------------
 
@@ -253,7 +253,7 @@ class Object(_petsc.Object):
         Blocks until this routine is executed by all processors owning
         the object.
 
-        .. note:: This routine calls `MPI_Barrier()` with the
+        .. note:: This routine calls ``MPI_Barrier()`` with the
            communicator of the PETSc object.
         """
         _petsc.PetscBarrier(self)
