@@ -4,10 +4,10 @@
 # Id: $Id$
 
 """
-PETSc Random
-============
+Random Numbers
+==============
 
-Random numbers generator.
+Random numbers generation.
 """
 
 # --------------------------------------------------------------------
@@ -16,12 +16,14 @@ __date__     = '$Date$'
 __version__  = '$Version$'
 __revision__ = '$Revision$'
 
-__docformat__ = 'reST'
+__docformat__ = 'reStructuredText'
 
 # --------------------------------------------------------------------
 
 __all__ = ['Random',
-           ]
+           'RandomRAND',
+           'RandomRAND48',
+           'RandomSPRNG',]
 
 # --------------------------------------------------------------------
 
@@ -48,15 +50,7 @@ class Random(Object):
 
     class Type(object):
         """
-        Random number generator types
-
-        Currently three types of random numbers are supported. These
-        types are equivalent when working with real numbers:
-        
-        - `DEFAULT`: both real and imaginary components are random.
-        - `REAL`:real component is random, imaginary component is 0.
-        - `IMAGINARY`: imaginary component is random, real component
-          is 0.
+        Random types.
         """
         # native
         PETSCRAND   = _petsc.PETSCRAND
@@ -122,11 +116,12 @@ class Random(Object):
         """
         return _petsc.PetscRandomGetSeed(self)
     
-    def setSeed(self, seed):
+    def setSeed(self, seed=None):
         """
         Sets the random seed and seeds the generator.
         """
-        _petsc.PetscRandomSetSeed(self, seed)
+        if seed is not None:
+            _petsc.PetscRandomSetSeed(self, seed)
         _petsc.PetscRandomSeed(self)
 
     def getInterval(self):
@@ -134,7 +129,7 @@ class Random(Object):
         Gets the interval over which the random numbers will be
         randomly distributed.  By default, this interval is [0,1).
 
-        :Return:
+        :Returns:
           - the interval '[low,high)' (as a tuple) over which the
             random numbers will be randomly distributed.  By
             default, this interval is [0,1).
@@ -144,7 +139,7 @@ class Random(Object):
     def setInterval(self, interval):
         """
         Sets the interval '[low,high)' over which the random numbers
-        will be randomly distributed.  By default, this interval is
+        will be randomly distributed. By default, this interval is
         [0,1).
 
         :Parameters:
