@@ -38,6 +38,9 @@ __all__ = ['SNES',
 from petsc4py.lib import _petsc
 
 from petsc4py.Object import Object
+from petsc4py.Vec    import Vec
+from petsc4py.Mat    import Mat
+from petsc4py.KSP    import KSP
 
 # --------------------------------------------------------------------
 
@@ -96,6 +99,8 @@ class SNES(Object):
           2-norm(x) where x is the current solution and xtol is the
           4th argument to `SNES.setTolerances()`
 
+        + CONVERGED_ITS - `
+
         + DIVERGED_FUNCTION_COUNT - The user provided function has
           been called more times then the final argument to
           `SNES.setTolerances()`
@@ -121,6 +126,7 @@ class SNES(Object):
         CONVERGED_FNORM_ABS      = _petsc.SNES_CONVERGED_FNORM_ABS
         CONVERGED_FNORM_RELATIVE = _petsc.SNES_CONVERGED_FNORM_RELATIVE
         CONVERGED_PNORM_RELATIVE = _petsc.SNES_CONVERGED_PNORM_RELATIVE
+        CONVERGED_ITS            = _petsc.SNES_CONVERGED_ITS
         CONVERGED_TR_DELTA       = _petsc.SNES_CONVERGED_TR_DELTA
         # iterating
         CONVERGED_ITERATING      = _petsc.SNES_CONVERGED_ITERATING
@@ -137,9 +143,10 @@ class SNES(Object):
         """
         Interface class for SNES ConvergenceTest objects
         """
-        DEFAULT = _petsc.SNESDefaultConvergenceTest
+        DEFAULT = _petsc.SNESDefaultConverged
+        SKIP    = _petsc.SNESSkipConverged
         def __call__(self, snes, its, xnorm, gnorm, fnorm):
-            """Calls SNES.ConvergenceTest.DEFAULT"""
+            """Call SNES.ConvergenceTest.DEFAULT"""
             return self.DEFAULT(snes, its, xnorm, gnorm, fnorm)
         
     class Monitor(object):
@@ -248,11 +255,14 @@ class SNES(Object):
     
     def computeFunction(self, x, y):
         """
+        Call the function that has been set with `SNES.setFunction()`.
         """
         _petsc.SNESComputeFunction(self, x, y)
         
     def computeJacobian(self, x, J, P=None):
         """
+        Computes the Jacobian matrix that has been set with
+        `SNES.setJacobian()`.
         """
         if P is None:
             P = J
@@ -294,7 +304,9 @@ class SNES(Object):
         """
         Get various parameters used in convergence tests.
         """
-        return _petsc.SNESGetTolerances(self)
+        tols = list(_petsc.SNESGetTolerances(self))
+        tols[0], tols[1] = tols[1], tols[0]
+        return tols
 
     def setTolerances(self,
                       rtol=None, atol=None, stol=None,
@@ -317,12 +329,12 @@ class SNES(Object):
         
     def setUseEW(self, flag, *targs, **kargs):
         """
-        Set alternative convergence test for the linear solvers within
-        an inexact Newton method.
+        Set alternative convergence criteria for the linear solvers
+        within an inexact Newton method.
         """
         _petsc.SNESSetUseEW(self, flag)
         if targs or kargs:
-            self.setParamsEW(*targs,**kargs)
+            self.setParamsEW(*targs, **kargs)
         
     def setParamsEW(self,
                     version=None,
@@ -333,7 +345,7 @@ class SNES(Object):
                     alpha2=None,
                     threshold=None):
         """
-        Sets parameters for Eisenstat-Walker convergence criteria for
+        Set parameters for Eisenstat-Walker convergence criteria for
         the linear solvers within an inexact Newton method.
         """
         parameters = [version, rtol_0, rtol_max,
@@ -342,6 +354,18 @@ class SNES(Object):
             if param is None:
                 parameters[i] = _petsc.PETSC_DEFAULT
         _petsc.SNESSetParametersEW(self, *parameters)
+
+    def getParamsEW(self):
+        """
+        Get parameters for Eisenstat-Walker convergence criteria for
+        the linear solvers within an inexact Newton method.
+        """
+        names  = ['version', 'rtol_0', 'rtol_max',
+                  'gamma', 'alpha', 'alpha2', 'threshold']
+        values = _petsc.SNESGetParametersEW(self)
+        return dict(zip(names, values))
+        
+
         
     def setMonitor(self, monitor):
         """
@@ -390,30 +414,51 @@ class SNES(Object):
         """
         return _petsc.SNESGetConvergenceHistory(self)
 
-    def getIterationNumber(self):
-        """
-        """
-        return _petsc.SNESGetIterationNumber(self)
-
     def getFunctionNorm(self):
         """
         """
         return _petsc.SNESGetFunctionNorm(self)
 
-    def getNumberLinearIterations(self):
+    def getIterationNumber(self):
         """
         """
-        return _petsc.SNESGetNumberLinearIterations(self)
+        return _petsc.SNESGetIterationNumber(self)
 
-    def getNumberUnsuccessfulSteps(self):
+    def getNonlinearStepFailures(self):
         """
         """
-        return _petsc.SNESGetNumberUnsuccessfulSteps(self)
+        return _petsc.SNESGetNonlinearStepFailures(self)
 
-    def setMaximumUnsuccessfulSteps(self, max_fails):
+    def setMaxNonlinearStepFailures(self, max_fails):
         """
         """
-        _petsc.SNESSetMaximumUnsuccessfulSteps(self, max_fails)
+        _petsc.SNESSetMaxNonlinearStepFailures(self, max_fails)
+
+    def getMaxNonlinearStepFailures(self):
+        """
+        """
+        return _petsc.SNESGetMaxNonlinearStepFailures(self)
+
+    def getLinearSolveIterations(self):
+        """
+        """
+        return _petsc.SNESGetLinearSolveIterations(self)
+
+    def getLinearSolveFailures(self):
+        """
+        """
+        return _petsc.SNESGetLinearSolveFailures(self)
+
+    def setMaxLinearSolveFailures(self, max_fails):
+        """
+        """
+        _petsc.SNESSetMaxLinearSolveFailures(self, max_fails)
+
+    def getMaxLinearSolveFailures(self):
+        """
+        """
+        return _petsc.SNESGetMaxLinearSolveFailures(self)
+
 
     appctx   = property(getApplicationContext, setApplicationContext)
     
@@ -426,12 +471,12 @@ class SNES(Object):
     soltol    = stol  = property(*_petsc.tolerance('stol',      2))
     max_it    = maxit = property(*_petsc.tolerance('max_it',    3))
     max_funcs = maxf  = property(*_petsc.tolerance('max_funcs', 4))
-    max_fails = property(getNumberUnsuccessfulSteps,
-                         setMaximumUnsuccessfulSteps)
+    max_fails = property(getMaxNonlinearStepFailures,
+                         setMaxNonlinearStepFailures)
 
     iternum    = its   = property(getIterationNumber)
     funcnorm   = fnorm = property(getFunctionNorm)
-    linear_its = property(getNumberLinearIterations)
+    linear_its = property(getLinearSolveIterations)
     converged  = property(getConverged)
     
 
@@ -462,7 +507,7 @@ class SNESLS(SNES):
         ls = _petsc.get_attr(SNESLS.LSType, ls)
         _petsc.SNESLineSearchSetType(self, ls)
         
-    def setLineSearchParams(self, alpha=None, maxsteps=None, steptol=None):
+    def setParamsLS(self, alpha=None, maxsteps=None, steptol=None):
         """
         Set the parameters associated with the line search routine in
         the Newton-based method SNESLS.
@@ -481,7 +526,9 @@ class SNESLS(SNES):
         alpha, maxsteps, steptol = params
         _petsc.SNESLineSearchSetParams(self, alpha, maxsteps, steptol)
 
-    def getLineSearchParams(self):
+    setLineSearchParams = setParamsLS
+
+    def getParamsLS(self):
         """
         Get the parameters associated with the line search
         routine in the Newton-based method SNESLS.
@@ -495,17 +542,27 @@ class SNESLS(SNES):
         """
         return _petsc.SNESLineSearchGetParams(self)
 
+    getLineSearchParams = getParamsLS
+
+
 class SNESTR(SNES):
     """
     Newton based nonlinear solver that uses a trust region.
     """
     __metaclass__ = SNES.Type(SNES.Type.TR)
 
+    def setParamsTR(self, tol=None):
+        """
+        Set the trust region parameters.
+        """
+        if tol is not None:
+            _petsc.SNESSetTrustRegionTolerance(self, tol)
+
     def setTrustRegionTolerance(self, tol):
         """
         Set the trust region parameter tolerance.
         """
         _petsc.SNESSetTrustRegionTolerance(self, tol)
-        
+
 
 # --------------------------------------------------------------------
