@@ -101,6 +101,7 @@ def GetVersion(patch=False, date=False, author=False):
     PETSc version information.
     """
     _data = _petsc.PetscGetVersion()
+    del _data[4]
     _version = tuple(_data[0:3])
     out = _version
     if patch or date or author:
@@ -333,6 +334,7 @@ class Sys(object):
         Return PETSc version information.
         """
         _data = _petsc.PetscGetVersion()
+        del _data[4]
         _version = tuple(_data[0:3])
         out = _version
         if patch or date or author:
@@ -353,6 +355,19 @@ class Sys(object):
             out = tuple(out)
         return out
 
+    @staticmethod
+    def getVersionInfo():
+        """
+        Return PETSc version information.
+        """
+        _keys = ('major', 'minor', 'subminor',
+                 'patch', 'release',
+                 'date', 'patchdate', 'authorinfo')
+        _vals = _petsc.PetscGetVersion()
+        _author = _vals[-1].split('\n')
+        _vals[-1] = [ln.strip() for ln in _author if ln]
+        return dict(zip(_keys,_vals))
+
     @staticmethod
     def isInitialized():
         """
