@@ -39,6 +39,7 @@ from petsc4py.lib import _vecops
 from petsc4py.lib import _numpy
 
 from petsc4py.Object import Object
+from petsc4py.IS     import IS
 
 # --------------------------------------------------------------------
 
@@ -139,7 +140,7 @@ class Vec(Object):
     
     def create(self, comm=None):
         """
-        Creates an empty vector object. The local and global sizes can
+        Create an empty vector object. The local and global sizes can
         be set with `setSizes()` and the type can then be set with
         `setType()` (or perhaps `setFromOptions()`).
 
@@ -156,7 +157,7 @@ class Vec(Object):
 
     def createSeq(self, size, bsize=None, comm=None):
         """
-        Creates and returns a sequential vector.
+        Create and returns a sequential vector.
 
         :Parameters:
            - `size`:  vector length.
@@ -175,7 +176,7 @@ class Vec(Object):
 
     def createMPI(self, size, bsize=None, comm=None):
         """
-        Creates and returns a parallel vector.
+        Create and returns a parallel vector.
 
         :Parameters:
           - `size`: sequence ``(n, N)`` with local and global vector
@@ -195,7 +196,7 @@ class Vec(Object):
 
     def createShared(self, size, bsize=None, comm=None):
         """
-        Creates and returns a parallel vector that uses shared memory.
+        Create and returns a parallel vector that uses shared memory.
 
         :Parameters:
           - `size`: sequence ``(n, N)`` with local and global vector
@@ -218,8 +219,7 @@ class Vec(Object):
 
     def createGhost(self, size, ghosts, bsize=None, comm=None):
         """
-        Creates a parallel vector with ghost padding on each
-        processor.
+        Create a parallel vector with ghost padding on each processor.
 
         :Parameters:
           - `size`: sequence ``(n, N)`` with local and global vector
@@ -275,19 +275,19 @@ class Vec(Object):
         
     def getSize(self):
         """
-        Returns the global number of elements of the vector.
+        Return the global number of elements of the vector.
         """
         return _petsc.VecGetSize(self)
 
     def getLocalSize(self):
         """
-        Returns the local number of elements of the vector.
+        Return the local number of elements of the vector.
         """
         return _petsc.VecGetLocalSize(self)
 
     def getSizes(self):
         """
-        Returns the local and global sizes of a vector.
+        Return the local and global sizes of a vector.
         """
         lsize = _petsc.VecGetLocalSize(self)
         gsize = _petsc.VecGetSize(self)
@@ -295,7 +295,8 @@ class Vec(Object):
 
     def setSizes(self, sizes, bsize=None):
         """
-        Sets the local and global sizes of a vector.
+        Sets the local and global sizes of a vector,
+        and optionally the block size.
         """
         comm = _petsc.PetscObjectGetComm(self)
         if _petsc.PetscCommGetSize(comm) == 1:
@@ -356,7 +357,7 @@ class Vec(Object):
           - `vec` : vector where to copy values (optional)
 
         :Returns:
-           - None if `vec` is provided. Otherwise, a new vector is
+           - `vec` if `vec` is provided. Otherwise, a new vector is
              created with `duplicate()`, values are copied to it, and
              that vector is returned.
         
@@ -372,22 +373,24 @@ class Vec(Object):
     @staticmethod
     def Load(viewer, vec_type=None):
         """
-        Loads and returns a vector that has been stored in binary
-        format with `view()`.
+        Load and return a vector that has been stored in binary format
+        with `view()`.
         """
         vec_type = _petsc.get_attr(Vec.Type, vec_type)
         return _petsc.VecLoad(viewer, vec_type)
 
-    def loadIntoVector(self, viewer):
+    def load(self, viewer):
         """
-        Loads a vector that has been stored in binary format
-        with `view()`.
+        Load a vector that has been stored in binary format with
+        `view()`.
         """
         _petsc.VecLoadIntoVector(viewer, self)
 
+    loadIntoVector = load
+
     def setOption(self, option):
         """
-        Sets an option for controling a vector's behavior.
+        Set an option for controling a vector's behavior.
         """
         try:
             options = iter(option)
@@ -399,25 +402,25 @@ class Vec(Object):
 
     def equal(self, vec):
         """
-        Compares two vectors.
+        Compare two vectors.
         """
         return bool(_petsc.VecEqual(self, vec))
 
     def dot(self, vec):
         """
-        Computes the vector dot product.
+        Compute the vector dot product.
         """
         return _petsc.VecDot(self, vec)
     
     def dotBegin(self, vec):
         """
-        Starts a split phase dot product computation.
+        Start a split phase dot product computation.
         """
         _petsc.VecDotBegin(self, vec)
 
     def dotEnd(self, vec):
         """
-        Ends a split phase dot product computation.
+        End a split phase dot product computation.
         """
         return _petsc.VecDotEnd(self, vec)
 
@@ -430,17 +433,19 @@ class Vec(Object):
                               
     def tDotBegin(self, vec):
         """
+        Start a split phase indefinite dot product computation.
         """
         _petsc.VecTDotBegin(self, vec)
 
     def tDotEnd(self, vec):
         """
+        End a split phase indefinite dot product computation.
         """
         return _petsc.VecTDotEnd(self, vec)
 
     def norm(self, norm_type=None):
         """
-        Computes the vector norm.
+        Compute the vector norm.
         """
         return _petsc.VecNorm(self, norm_type)
     
@@ -456,13 +461,13 @@ class Vec(Object):
     
     def sum(self):
         """
-        Computes the sum of all the components of a vector.
+        Compute the sum of all the components of a vector.
         """
         return _petsc.VecSum(self)
                              
     def min(self):
         """
-        Determines the minimum vector component and its location.
+        Determine the minimum vector component and its location.
         """
         return tuple(_petsc.VecMin(self))
 
@@ -474,7 +479,7 @@ class Vec(Object):
                              
     def normalize(self):
         """
-        Normalizes a vector by 2-norm and returns original 2-norm.
+        Normalize a vector by 2-norm and returns original 2-norm.
         """
         return _petsc.VecNormalize(self)
 
@@ -565,7 +570,7 @@ class Vec(Object):
 
     def permute(self, order, invert=False):
         """
-        Permutes a vector in place using the given ordering
+        Permute a vector in place using the given ordering
 
         :Parameters:
           - `order`: index set with permutation
@@ -575,7 +580,7 @@ class Vec(Object):
                                  
     def getArray(self, array=None):
         """
-        Returns an array that contains this processor's portion of the
+        Return an array that contains this processor's portion of the
         vector data. This method makes a copy.
         """
         if array is None:
@@ -586,13 +591,13 @@ class Vec(Object):
 
     def setArray(self, array):
         """
-        Sets this processor's portion of the vector data.
+        Set this processor's portion of the vector data.
         """
         _petsc.VecSetArray(self, array)
 
     def placeArray(self, array):
         """
-        Allows to replace the array in a vector with an array provided
+        Allow to replace the array in a vector with an array provided
         by the user. This is useful to avoid copying an array into a
         vector.
 
@@ -606,8 +611,8 @@ class Vec(Object):
 
     def resetArray(self):
         """
-        Resets a vector to use its default memory. Call this 
-        after the use of `placeArray()`.
+        Reset a vector to use its default memory. Call this after the
+        use of `placeArray()`.
         """
         _petsc.VecResetArray(self)
 
@@ -619,7 +624,7 @@ class Vec(Object):
 
     def getValues(self, indices, values=None):
         """
-        Gets a block of values from a vector.
+        Get a block of values from a vector.
         """
         if values is None:
             indices = _numpy.asarray(indices, _petsc.PetscInt)
@@ -630,13 +635,13 @@ class Vec(Object):
 
     def setValue(self, index, value, insert_mode=None):
         """
-        Sets a single value.
+        Set a single value.
         """
         _petsc.VecSetValue(self, index, value, insert_mode)
 
     def setValues(self, indices, values, insert_mode=None):
         """
-        Inserts or adds values into certain locations of a vector.
+        Insert or add values into certain locations of a vector.
 
         :Parameters:
           - `indices`: array of indices.
@@ -649,7 +654,7 @@ class Vec(Object):
         
     def setLGMapping(self, lgmap):
         """
-        Sets a local numbering to global numbering used by
+        Set a local numbering to global numbering used by
         `setValuesLocal()` to allow users to insert vector entries
         using a local (per-processor) numbering.
         """
@@ -684,21 +689,21 @@ class Vec(Object):
 
     def assemblyBegin(self):
         """
-        Begins assembling the vector.  This routine should be called
+        Begin assembling the vector.  This routine should be called
         after completing all calls to `setValues()`.
         """
         _petsc.VecAssemblyBegin(self)
 
     def assemblyEnd(self):
         """
-        Completes assembling the vector.  This routine should be
-        called after `assemblyBegin()`.
+        Complete assembling the vector.  This routine should be called
+        after `assemblyBegin()`.
         """
         _petsc.VecAssemblyEnd(self)
 
     def assemble(self):
         """
-        Calls `assemblyBegin()` and `assemblyEnd()`.
+        Call `assemblyBegin()` and `assemblyEnd()`.
         """
         _petsc.VecAssemblyBegin(self)
         _petsc.VecAssemblyEnd(self)
@@ -739,8 +744,7 @@ class Vec(Object):
 
     def getLocalForm(self):
         """
-        Obtains the local ghosted representation of a parallel
-        vector.
+        Obtain the local ghosted representation of a parallel vector.
 
         .. note:: This routine does not actually update the ghost
            values, but rather it returns a sequential vector that
@@ -753,21 +757,21 @@ class Vec(Object):
 
     def ghostUpdateBegin(self, insert_mode, scatter_mode):
         """
-        Begins the vector scatter to update the vector from local
+        Begin the vector scatter to update the vector from local
         representation to global or global representation to local.
         """
         _petsc.VecGhostUpdateBegin(self, insert_mode, scatter_mode)
 
     def ghostUpdateEnd(self, insert_mode, scatter_mode):
         """
-        Ends the vector scatter to update the vector from local
+        End the vector scatter to update the vector from local
         representation to global or global representation to local.
         """
         _petsc.VecGhostUpdateEnd(self, insert_mode, scatter_mode)
 
     def ghostUpdate(self, insert_mode, scatter_mode):
         """
-        Updates the vector from local representation to global or
+        Update the vector from local representation to global or
         global representation to local.
         """
         _petsc.VecGhostUpdateBegin(self, insert_mode, scatter_mode)
@@ -841,7 +845,7 @@ class Scatter(Object):
     This scatter is far more general than the conventional MPI
     scatter, since it can be a gather or a scatter or a combination,
     depending on the indices ``ix`` and ``iy``.  If ``x`` is a
-    parallel vector and ``y`` is sequential, `Scatter()` can serve to
+    parallel vector and ``y`` is sequential, `Scatter` can serve to
     gather values to a single processor.  Similarly, if ``y`` is
     parallel and ``x`` sequential, the routine can scatter from one
     processor to many processors.
@@ -882,7 +886,7 @@ class Scatter(Object):
 
     def create(self, vec_from, is_from, vec_to, is_to):
         """
-        Creates a vector scatter context.
+        Create a vector scatter context.
 
         :Parameters:
           - `vec_from`: a vector that defines the shape (parallel data
@@ -899,14 +903,14 @@ class Scatter(Object):
     
     def copy(self):
         """
-        Makes a copy of a scatter context.
+        Make a copy of a scatter context.
         """
         return _petsc.VecScatterCopy(self)
     
     @staticmethod
     def toAll(vec):
         """
-        Creates a scatter context that copies all vector values to
+        Create a scatter context that copies all vector values to
         each processor.
 
         :Parameters: 
@@ -933,7 +937,7 @@ class Scatter(Object):
     @staticmethod
     def toZero(vec):
         """
-        Creates a scatter context that copies all vector values to a
+        Create a scatter context that copies all vector values to a
         vector on the zeroth processor
 
         :Returns:
@@ -960,16 +964,16 @@ class Scatter(Object):
         Begins a generalized scatter from one vector to
         another. Complete the scattering phase with `scatterEnd()`.
         """
-        _petsc.VecScatterBegin(vec_from, vec_to,
-                               insert_mode, scatter_mode, self)
+        _petsc.VecScatterBegin(self, vec_from, vec_to,
+                               insert_mode, scatter_mode)
 
     def end(self, vec_from, vec_to, insert_mode, scatter_mode):
         """
         Ends a generalized scatter from one vector to another.
         Call after first calling `scatterBegin()`.
         """
-        _petsc.VecScatterEnd(vec_from, vec_to,
-                             insert_mode, scatter_mode, self)
+        _petsc.VecScatterEnd(self, vec_from, vec_to,
+                             insert_mode, scatter_mode)
 
     scatterBegin = begin
 
@@ -980,10 +984,10 @@ class Scatter(Object):
         """
         Generalized scatter from one vector to another.
         """
-        _petsc.VecScatterBegin(vec_from, vec_to,
-                               insert_mode, scatter_mode, self)
-        _petsc.VecScatterEnd(vec_from, vec_to,
-                             insert_mode, scatter_mode, self)
+        _petsc.VecScatterBegin(self, vec_from, vec_to,
+                               insert_mode, scatter_mode)
+        _petsc.VecScatterEnd(self, vec_from, vec_to,
+                             insert_mode, scatter_mode)
     
 
 # --------------------------------------------------------------------
