@@ -39,7 +39,7 @@ support for distributed arrays.
 
 __author__    = 'Lisandro Dalcin'
 __credits__   = "PETSc Team <petsc-maint@mcs.anl.gov>"
-__version__   = '0.7.2'
+__version__   = '0.7.3'
 __revision__  = '$Revision$'
 
 __docformat__ = 'reStructuredText'
@@ -107,7 +107,7 @@ def main(*args):
     #    scatter = PETSc.Scatter().create(v,i,v,i)
     if 'mat' in args:
         mat = PETSc.Mat().create(PETSc.COMM_SELF)
-        mat.setSizes(0)
+        mat.setSizes(0, 0)
         mat.setFromOptions()
         del mat
     if 'ksp' in args:
