@@ -38,13 +38,15 @@ def Import(arch=None):
         return petscext
     # determine PETSC_ARCH value
     if arch is None:
-        arch = os.environ.get('PETSC_ARCH')
-        if not arch:
+        petsc_arch = os.environ.get('PETSC_ARCH')
+        if not petsc_arch:
             petsc_cfg = open(os.path.join(__path__[0], 'petsc.cfg'))
             lines = petsc_cfg.read().replace(' ', '').splitlines()
             petsc_cfg.close()
             petsc_cfg = dict(line.split('=') for line in lines)
-            arch = petsc_cfg['PETSC_ARCH'].split(',')[0]
+            petsc_arch = petsc_cfg['PETSC_ARCH']
+        psep = os.path.pathsep
+        arch = [arch for arch in petsc_arch.split(psep) if arch][0]
         mpath = os.path.join(__path__[0], arch)
         if not os.path.isdir(mpath):
             raise ImportError("invalid 'PETSC_ARCH': '%s'" % arch)
@@ -61,7 +63,7 @@ def Import(arch=None):
     petscext = imp.load_module(mname, fo, fn, stuff)
     petscext.__arch__ = arch
     sys.modules[__name__]._petscext = petscext
-    return petscext 
+    return petscext
 
 
 # --------------------------------------------------------------------
