@@ -36,6 +36,14 @@ def get_attr(obj, attr, default=None):
 def PetscCommSetComm(self, comm):
     _petsc.PetscCommSetComm(self, comm)
     
+# Helper function to get a type.
+def get_type(obj, otype):
+    if type(otype) is str:
+        types = getattr(obj, 'Type', None)
+        if types is not None:
+            attr = otype.replace('-','_').upper()
+            otype = getattr(types, attr, otype)
+    return otype
 
 # Helper functions to check block sizes
 def obj_bsize(bsz, default=None):
