@@ -1,3 +1,5 @@
+#include "petsclib.h"
+
 #define PETSCMAT_DLL
 #include "src/mat/impls/is/matis.c"
 #undef  PETSCMAT_DLL
@@ -6,10 +8,6 @@
 #include "src/ksp/pc/impls/schur/schur.c"
 #undef PETSCKSP_DLL
 
-#define PETSCSNES_DLL
-/*#include "src/sens/impls/fn/fn.c"*/
-#undef PETSCSNES_DLL
-
 #define PETSCTS_DLL
 #include "src/ts/impls/implicit/user/user.c"
 #undef PETSCTS_DLL
