@@ -26,8 +26,16 @@ class TestLib(unittest.TestCase):
                     sym = m.group()
                     symbols.add(sym)
         from petsc4py.lib import _petsc
+        undef = []
         for sym in symbols:
-            getattr(_petsc, sym)
+            try:
+                getattr(_petsc, sym)
+            except AttributeError:
+                undef.append(sym)
+        if undef:
+            raise AttributeError('undefined symbols: ' + str(undef))
+        
+                
 
 # --------------------------------------------------------------------
 
