@@ -6,12 +6,13 @@ import unittest
 class TestVecBase(object):
 
     CLASS = None
+    COMM  = None
     TARGS = []
     KARGS = {}
     
     def setUp(self):
         v = PETSc.Vec()
-        v.create()
+        v.create(self.COMM)
         v.setSizes(100)
         v.setType(self.CLASS.TYPE)
         self.vec = v
@@ -163,15 +164,18 @@ class TestVecBase(object):
 
 class TestVecSeq(TestVecBase, unittest.TestCase):
     CLASS = PETSc.VecSeq
+    COMM  = PETSc.COMM_SELF
 
 class TestVecMPI(TestVecBase, unittest.TestCase):
     CLASS = PETSc.VecMPI
+    COMM  = PETSc.COMM_WORLD
 
 class TestVecShared(TestVecBase, unittest.TestCase):
     if PETSc.COMM_WORLD.getSize() == 1:
         CLASS = PETSc.VecShared
     else:
         CLASS = PETSc.VecMPI
+    COMM  = PETSc.COMM_WORLD
 
 #class TestVecSieve(TestVecBase, unittest.TestCase):
 #    CLASS = PETSc.VecSieve
